==> findent_4.3.5.orig.tar.gz: findent-4.3.5/src/builtparser.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_YY_PARSER_HPP_INCLUDED
# define YY_YY_PARSER_HPP_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    MODULE = 258,                  /* MODULE  */
    SUBFUN = 259,                  /* SUBFUN  */
    ENTRY = 260,                   /* ENTRY  */
    SUBMODULE = 261,               /* SUBMODULE  */
    MODULESUBROUTINE = 262,        /* MODULESUBROUTINE  */
    MODULEFUNCTION = 263,          /* MODULEFUNCTION  */
    END = 264,                     /* END  */
    ENDSUBROUTINE = 265,           /* ENDSUBROUTINE  */
    ENDFUNCTION = 266,             /* ENDFUNCTION  */
    ENDPROGRAM = 267,              /* ENDPROGRAM  */
    ENDMODULE = 268,               /* ENDMODULE  */
    ENDSUBMODULE = 269,            /* ENDSUBMODULE  */
    IF = 270,                      /* IF  */
    THEN = 271,                    /* THEN  */
    ELSE = 272,                    /* ELSE  */
    ELSEIF = 273,                  /* ELSEIF  */
    ENDIF = 274,                   /* ENDIF  */
    SIMPLEIF = 275,                /* SIMPLEIF  */
    NWAYIF = 276,                  /* NWAYIF  */
    WHERE = 277,                   /* WHERE  */
    ENDWHERE = 278,                /* ENDWHERE  */
    FORALL = 279,                  /* FORALL  */
    ENDFORALL = 280,               /* ENDFORALL  */
    ELSEWHERE = 281,               /* ELSEWHERE  */
    DO = 282,                      /* DO  */
    DOCOMMA = 283,                 /* DOCOMMA  */
    DOWHILE = 284,                 /* DOWHILE  */
    DOCONCURRENT = 285,            /* DOCONCURRENT  */
    ENDDO = 286,                   /* ENDDO  */
    SELECTCASE = 287,              /* SELECTCASE  */
    SELECTTYPE = 288,              /* SELECTTYPE  */
    ENDSELECT = 289,               /* ENDSELECT  */
    CASE = 290,                    /* CASE  */
    CASEDEFAULT = 291,             /* CASEDEFAULT  */
    TYPEIS = 292,                  /* TYPEIS  */
    CLASSIS = 293,                 /* CLASSIS  */
    CLASSDEFAULT = 294,            /* CLASSDEFAULT  */
    SELECTRANK = 295,              /* SELECTRANK  */
    RANK = 296,                    /* RANK  */
    RANKDEFAULT = 297,             /* RANKDEFAULT  */
    INTERFACE = 298,               /* INTERFACE  */
    INTERFACE1 = 299,              /* INTERFACE1  */
    ABSTRACTINTERFACE = 300,       /* ABSTRACTINTERFACE  */
    ENDINTERFACE = 301,            /* ENDINTERFACE  */
    CONTAINS = 302,                /* CONTAINS  */
    BLOCK = 303,                   /* BLOCK  */
    ENDBLOCK = 304,                /* ENDBLOCK  */
    BLOCKDATA = 305,               /* BLOCKDATA  */
    ENDBLOCKDATA = 306,            /* ENDBLOCKDATA  */
    ASSOCIATE = 307,               /* ASSOCIATE  */
    ENDASSOCIATE = 308,            /* ENDASSOCIATE  */
    CRITICAL = 309,                /* CRITICAL  */
    ENDCRITICAL = 310,             /* ENDCRITICAL  */
    CHANGETEAM = 311,              /* CHANGETEAM  */
    ENDTEAM = 312,                 /* ENDTEAM  */
    ENUM = 313,                    /* ENUM  */
    ENDENUM = 314,                 /* ENDENUM  */
    ASSIGNMENT = 315,              /* ASSIGNMENT  */
    ASSIGN = 316,                  /* ASSIGN  */
    TO = 317,                      /* TO  */
    GOTO = 318,                    /* GOTO  */
    GOTO_COMPUTED = 319,           /* GOTO_COMPUTED  */
    GOTO_ASSIGNED = 320,           /* GOTO_ASSIGNED  */
    READ = 321,                    /* READ  */
    PRINT = 322,                   /* PRINT  */
    WRITE = 323,                   /* WRITE  */
    IO = 324,                      /* IO  */
    IOLIST = 325,                  /* IOLIST  */
    STARTIO = 326,                 /* STARTIO  */
    LABELIS = 327,                 /* LABELIS  */
    OTHER = 328,                   /* OTHER  */
    MODULEPROCEDURE = 329,         /* MODULEPROCEDURE  */
    PROCEDURE = 330,               /* PROCEDURE  */
    ENDPROCEDURE = 331,            /* ENDPROCEDURE  */
    TIDENTIFIER = 332,             /* TIDENTIFIER  */
    BLANK = 333,                   /* BLANK  */
    CHAR = 334,                    /* CHAR  */
    FINDFORMAT = 335,              /* FINDFORMAT  */
    UNKNOWN = 336,                 /* UNKNOWN  */
    FREE = 337,                    /* FREE  */
    FIXED = 338,                   /* FIXED  */
    UNSURE = 339,                  /* UNSURE  */
    PROBFREE = 340,                /* PROBFREE  */
    FINDENTFIX = 341,              /* FINDENTFIX  */
    FIXFINDENTFIX = 342,           /* FIXFINDENTFIX  */
    P_ON = 343,                    /* P_ON  */
    P_OFF = 344,                   /* P_OFF  */
    SCANFIXPRE = 345,              /* SCANFIXPRE  */
    CPP_IF = 346,                  /* CPP_IF  */
    CPP_ENDIF = 347,               /* CPP_ENDIF  */
    CPP_ELSE = 348,                /* CPP_ELSE  */
    CPP_ELIF = 349,                /* CPP_ELIF  */
    CPP = 350,                     /* CPP  */
    COCO_IF = 351,                 /* COCO_IF  */
    COCO_ENDIF = 352,              /* COCO_ENDIF  */
    COCO_ELSE = 353,               /* COCO_ELSE  */
    COCO_ELIF = 354,               /* COCO_ELIF  */
    COCO = 355,                    /* COCO  */
    FYPP_IF = 356,                 /* FYPP_IF  */
    FYPP_ENDIF = 357,              /* FYPP_ENDIF  */
    FYPP_ELSE = 358,               /* FYPP_ELSE  */
    FYPP_ELIF = 359,               /* FYPP_ELIF  */
    FYPP = 360,                    /* FYPP  */
    INCLUDE = 361,                 /* INCLUDE  */
    INCLUDE_CPP = 362,             /* INCLUDE_CPP  */
    INCLUDE_CPP_STD = 363,         /* INCLUDE_CPP_STD  */
    INCLUDE_COCO = 364,            /* INCLUDE_COCO  */
    INCLUDE_FYPP = 365,            /* INCLUDE_FYPP  */
    INCFILENAME = 366,             /* INCFILENAME  */
    USE = 367,                     /* USE  */
    SEGMENT = 368,                 /* SEGMENT  */
    ENDSEGMENT = 369,              /* ENDSEGMENT  */
    ESOPE = 370,                   /* ESOPE  */
    IDENTIFIER = 371,              /* IDENTIFIER  */
    CIDENTIFIER = 372,             /* CIDENTIFIER  */
    SKIP = 373,                    /* SKIP  */
    SKIPALL = 374,                 /* SKIPALL  */
    SKIPNOOP = 375,                /* SKIPNOOP  */
    SKIPNOS = 376,                 /* SKIPNOS  */
    KEYWORD = 377,                 /* KEYWORD  */
    ELEMENTAL = 378,               /* ELEMENTAL  */
    IMPURE = 379,                  /* IMPURE  */
    PURE = 380,                    /* PURE  */
    SIMPLE = 381,                  /* SIMPLE  */
    RECURSIVE = 382,               /* RECURSIVE  */
    NON_RECURSIVE = 383,           /* NON_RECURSIVE  */
    SUBROUTINE = 384,              /* SUBROUTINE  */
    FUNCTION = 385,                /* FUNCTION  */
    PROGRAM = 386,                 /* PROGRAM  */
    EOL = 387,                     /* EOL  */
    NAMED_LABEL = 388,             /* NAMED_LABEL  */
    STLABEL = 389,                 /* STLABEL  */
    LABEL = 390,                   /* LABEL  */
    LABELS = 391,                  /* LABELS  */
    LABELLIST = 392,               /* LABELLIST  */
    CALL = 393,                    /* CALL  */
    STARTCALL = 394,               /* STARTCALL  */
    CALLLIST = 395,                /* CALLLIST  */
    TYPE = 396,                    /* TYPE  */
    ENDTYPE = 397,                 /* ENDTYPE  */
    CLASS = 398,                   /* CLASS  */
    BASICTYPE = 399,               /* BASICTYPE  */
    TYPEC = 400,                   /* TYPEC  */
    QSTRING = 401,                 /* QSTRING  */
    HSTRING = 402,                 /* HSTRING  */
    LR = 403,                      /* LR  */
    LRB = 404,                     /* LRB  */
    DOTOPERATOR = 405,             /* DOTOPERATOR  */
    I_NUMBER = 406,                /* I_NUMBER  */
    UNCLASSIFIED = 407,            /* UNCLASSIFIED  */
    ERROR = 408,                   /* ERROR  */
    OMP = 409,                     /* OMP  */
    SCANOMPFIXED = 410,            /* SCANOMPFIXED  */
    SCANOMPFREE = 411,             /* SCANOMPFREE  */
    DEF = 412,                     /* DEF  */
    EXEC = 413,                    /* EXEC  */
    ENDDEF = 414,                  /* ENDDEF  */
    NONE = 415,                    /* NONE  */
    LAST_TOKEN = 416               /* LAST_TOKEN  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef int YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;


int yyparse (void);


#endif /* !YY_YY_PARSER_HPP_INCLUDED  */

==> findent_4.3.6.orig.tar.gz: findent-4.3.6/src/builtparser.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_YY_PARSER_HPP_INCLUDED
# define YY_YY_PARSER_HPP_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    MODULE = 258,                  /* MODULE  */
    SUBFUN = 259,                  /* SUBFUN  */
    ENTRY = 260,                   /* ENTRY  */
    SUBMODULE = 261,               /* SUBMODULE  */
    MODULESUBROUTINE = 262,        /* MODULESUBROUTINE  */
    MODULEFUNCTION = 263,          /* MODULEFUNCTION  */
    END = 264,                     /* END  */
    ENDSUBROUTINE = 265,           /* ENDSUBROUTINE  */
    ENDFUNCTION = 266,             /* ENDFUNCTION  */
    ENDPROGRAM = 267,              /* ENDPROGRAM  */
    ENDMODULE = 268,               /* ENDMODULE  */
    ENDSUBMODULE = 269,            /* ENDSUBMODULE  */
    IF = 270,                      /* IF  */
    THEN = 271,                    /* THEN  */
    ELSE = 272,                    /* ELSE  */
    ELSEIF = 273,                  /* ELSEIF  */
    ENDIF = 274,                   /* ENDIF  */
    SIMPLEIF = 275,                /* SIMPLEIF  */
    NWAYIF = 276,                  /* NWAYIF  */
    WHERE = 277,                   /* WHERE  */
    ENDWHERE = 278,                /* ENDWHERE  */
    FORALL = 279,                  /* FORALL  */
    ENDFORALL = 280,               /* ENDFORALL  */
    ELSEWHERE = 281,               /* ELSEWHERE  */
    DO = 282,                      /* DO  */
    DOCOMMA = 283,                 /* DOCOMMA  */
    DOWHILE = 284,                 /* DOWHILE  */
    DOCONCURRENT = 285,            /* DOCONCURRENT  */
    ENDDO = 286,                   /* ENDDO  */
    SELECTCASE = 287,              /* SELECTCASE  */
    SELECTTYPE = 288,              /* SELECTTYPE  */
    ENDSELECT = 289,               /* ENDSELECT  */
    CASE = 290,                    /* CASE  */
    CASEDEFAULT = 291,             /* CASEDEFAULT  */
    TYPEIS = 292,                  /* TYPEIS  */
    CLASSIS = 293,                 /* CLASSIS  */
    CLASSDEFAULT = 294,            /* CLASSDEFAULT  */
    SELECTRANK = 295,              /* SELECTRANK  */
    RANK = 296,                    /* RANK  */
    RANKDEFAULT = 297,             /* RANKDEFAULT  */
    INTERFACE = 298,               /* INTERFACE  */
    INTERFACE1 = 299,              /* INTERFACE1  */
    ABSTRACTINTERFACE = 300,       /* ABSTRACTINTERFACE  */
    ENDINTERFACE = 301,            /* ENDINTERFACE  */
    CONTAINS = 302,                /* CONTAINS  */
    BLOCK = 303,                   /* BLOCK  */
    ENDBLOCK = 304,                /* ENDBLOCK  */
    BLOCKDATA = 305,               /* BLOCKDATA  */
    ENDBLOCKDATA = 306,            /* ENDBLOCKDATA  */
    ASSOCIATE = 307,               /* ASSOCIATE  */
    ENDASSOCIATE = 308,            /* ENDASSOCIATE  */
    CRITICAL = 309,                /* CRITICAL  */
    ENDCRITICAL = 310,             /* ENDCRITICAL  */
    CHANGETEAM = 311,              /* CHANGETEAM  */
    ENDTEAM = 312,                 /* ENDTEAM  */
    ENUM = 313,                    /* ENUM  */
    ENDENUM = 314,                 /* ENDENUM  */
    ASSIGNMENT = 315,              /* ASSIGNMENT  */
    ASSIGN = 316,                  /* ASSIGN  */
    TO = 317,                      /* TO  */
    GOTO = 318,                    /* GOTO  */
    GOTO_COMPUTED = 319,           /* GOTO_COMPUTED  */
    GOTO_ASSIGNED = 320,           /* GOTO_ASSIGNED  */
    READ = 321,                    /* READ  */
    PRINT = 322,                   /* PRINT  */
    WRITE = 323,                   /* WRITE  */
    IO = 324,                      /* IO  */
    IOLIST = 325,                  /* IOLIST  */
    STARTIO = 326,                 /* STARTIO  */
    LABELIS = 327,                 /* LABELIS  */
    OTHER = 328,                   /* OTHER  */
    MODULEPROCEDURE = 329,         /* MODULEPROCEDURE  */
    PROCEDURE = 330,               /* PROCEDURE  */
    ENDPROCEDURE = 331,            /* ENDPROCEDURE  */
    TIDENTIFIER = 332,             /* TIDENTIFIER  */
    BLANK = 333,                   /* BLANK  */
    CHAR = 334,                    /* CHAR  */
    FINDFORMAT = 335,              /* FINDFORMAT  */
    UNKNOWN = 336,                 /* UNKNOWN  */
    FREE = 337,                    /* FREE  */
    FIXED = 338,                   /* FIXED  */
    UNSURE = 339,                  /* UNSURE  */
    PROBFREE = 340,                /* PROBFREE  */
    FINDENTFIX = 341,              /* FINDENTFIX  */
    FIXFINDENTFIX = 342,           /* FIXFINDENTFIX  */
    P_ON = 343,                    /* P_ON  */
    P_OFF = 344,                   /* P_OFF  */
    SCANFIXPRE = 345,              /* SCANFIXPRE  */
    CPP_IF = 346,                  /* CPP_IF  */
    CPP_ENDIF = 347,               /* CPP_ENDIF  */
    CPP_ELSE = 348,                /* CPP_ELSE  */
    CPP_ELIF = 349,                /* CPP_ELIF  */
    CPP = 350,                     /* CPP  */
    COCO_IF = 351,                 /* COCO_IF  */
    COCO_ENDIF = 352,              /* COCO_ENDIF  */
    COCO_ELSE = 353,               /* COCO_ELSE  */
    COCO_ELIF = 354,               /* COCO_ELIF  */
    COCO = 355,                    /* COCO  */
    FYPP_IF = 356,                 /* FYPP_IF  */
    FYPP_ENDIF = 357,              /* FYPP_ENDIF  */
    FYPP_ELSE = 358,               /* FYPP_ELSE  */
    FYPP_ELIF = 359,               /* FYPP_ELIF  */
    FYPP = 360,                    /* FYPP  */
    INCLUDE = 361,                 /* INCLUDE  */
    INCLUDE_CPP = 362,             /* INCLUDE_CPP  */
    INCLUDE_CPP_STD = 363,         /* INCLUDE_CPP_STD  */
    INCLUDE_COCO = 364,            /* INCLUDE_COCO  */
    INCLUDE_FYPP = 365,            /* INCLUDE_FYPP  */
    INCFILENAME = 366,             /* INCFILENAME  */
    USE = 367,                     /* USE  */
    SEGMENT = 368,                 /* SEGMENT  */
    ENDSEGMENT = 369,              /* ENDSEGMENT  */
    ESOPE = 370,                   /* ESOPE  */
    STRUCTURE = 371,               /* STRUCTURE  */
    UNION = 372,                   /* UNION  */
    MAP = 373,                     /* MAP  */
    ENDSTRUCTURE = 374,            /* ENDSTRUCTURE  */
    ENDUNION = 375,                /* ENDUNION  */
    ENDMAP = 376,                  /* ENDMAP  */
    IDENTIFIER = 377,              /* IDENTIFIER  */
    CIDENTIFIER = 378,             /* CIDENTIFIER  */
    SKIP = 379,                    /* SKIP  */
    SKIPALL = 380,                 /* SKIPALL  */
    SKIPNOOP = 381,                /* SKIPNOOP  */
    SKIPNOS = 382,                 /* SKIPNOS  */
    KEYWORD = 383,                 /* KEYWORD  */
    ELEMENTAL = 384,               /* ELEMENTAL  */
    IMPURE = 385,                  /* IMPURE  */
    PURE = 386,                    /* PURE  */
    SIMPLE = 387,                  /* SIMPLE  */
    RECURSIVE = 388,               /* RECURSIVE  */
    NON_RECURSIVE = 389,           /* NON_RECURSIVE  */
    SUBROUTINE = 390,              /* SUBROUTINE  */
    FUNCTION = 391,                /* FUNCTION  */
    PROGRAM = 392,                 /* PROGRAM  */
    EOL = 393,                     /* EOL  */
    NAMED_LABEL = 394,             /* NAMED_LABEL  */
    STLABEL = 395,                 /* STLABEL  */
    LABEL = 396,                   /* LABEL  */
    LABELS = 397,                  /* LABELS  */
    LABELLIST = 398,               /* LABELLIST  */
    CALL = 399,                    /* CALL  */
    STARTCALL = 400,               /* STARTCALL  */
    CALLLIST = 401,                /* CALLLIST  */
    TYPE = 402,                    /* TYPE  */
    ENDTYPE = 403,                 /* ENDTYPE  */
    CLASS = 404,                   /* CLASS  */
    BASICTYPE = 405,               /* BASICTYPE  */
    TYPEC = 406,                   /* TYPEC  */
    QSTRING = 407,                 /* QSTRING  */
    HSTRING = 408,                 /* HSTRING  */
    LR = 409,                      /* LR  */
    LRB = 410,                     /* LRB  */
    DOTOPERATOR = 411,             /* DOTOPERATOR  */
    I_NUMBER = 412,                /* I_NUMBER  */
    UNCLASSIFIED = 413,            /* UNCLASSIFIED  */
    ERROR = 414,                   /* ERROR  */
    OMP = 415,                     /* OMP  */
    SCANOMPFIXED = 416,            /* SCANOMPFIXED  */
    SCANOMPFREE = 417,             /* SCANOMPFREE  */
    DEF = 418,                     /* DEF  */
    EXEC = 419,                    /* EXEC  */
    ENDDEF = 420,                  /* ENDDEF  */
    NONE = 421,                    /* NONE  */
    LAST_TOKEN = 422               /* LAST_TOKEN  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef int YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;


int yyparse (void);


#endif /* !YY_YY_PARSER_HPP_INCLUDED  */
